==> ejc-law-impl-3.0.0-20221123.002750-29-sources.jar: com/ejianc/business/law/controller/LedgerController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.FrozenFundEntity;
import com.ejianc.business.law.bean.InfoRegisterEntity;
import com.ejianc.business.law.bean.ThawFundEntity;
import com.ejianc.business.law.service.IFrozenFundService;
import com.ejianc.business.law.service.IInfoRegisterService;
import com.ejianc.business.law.service.IThawFundService;
import com.ejianc.business.law.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.law.bean.LedgerEntity;
import com.ejianc.business.law.service.ILedgerService;

/**
 * 案件台账
 *
 * @author generator
 */
@Controller
@RequestMapping("ledger")
public class LedgerController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ILedgerService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<LedgerVO> saveOrUpdate(@RequestBody LedgerVO saveOrUpdateVO) {
        LedgerEntity entity = BeanMapper.map(saveOrUpdateVO, LedgerEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);
        LedgerVO vo = BeanMapper.map(entity, LedgerVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }


    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @Autowired
    private IInfoRegisterService infoRegisterService;
    @Autowired
    private IFrozenFundService frozenFundService;
    @Autowired
    private IThawFundService thawFundService;

    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<LedgerVO> queryDetail(Long id) {
        LedgerEntity entity = service.selectById(id);
        LedgerVO vo = BeanMapper.map(entity, LedgerVO.class);

        List<InfoRegisterEntity> infoRegisterEntity = infoRegisterService.list(Wrappers.<InfoRegisterEntity>lambdaQuery()
                .eq(InfoRegisterEntity::getCaseId, entity.getCaseId()));
        List<FrozenFundEntity> frozenFundEntity = frozenFundService.list(Wrappers.<FrozenFundEntity>lambdaQuery()
                .eq(FrozenFundEntity::getCaseId, entity.getCaseId()));
        List<ThawFundEntity> thawFundEntity = thawFundService.list(Wrappers.<ThawFundEntity>lambdaQuery()
                .eq(ThawFundEntity::getCaseId, entity.getCaseId()));
        //转换类型
        List<InfoRegisterVO> infoRegisterVOS = BeanMapper.mapList(infoRegisterEntity, InfoRegisterVO.class);
        List<FrozenFundVO> frozenFundVO = BeanMapper.mapList(frozenFundEntity, FrozenFundVO.class);
        List<ThawFundVO> thawFundVO = BeanMapper.mapList(thawFundEntity, ThawFundVO.class);
        //封装返回

        vo.setInfoRegisterVOS(infoRegisterVOS);
        vo.setFrozenFundVOS(frozenFundVO);
        vo.setThawFundVOS(thawFundVO);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<LedgerVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (LedgerVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(LedgerVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<LedgerVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            //普通组织
            commonOrgIds.add(org.getId());

        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<LedgerEntity> page = service.queryPage(param, false);
        IPage<LedgerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), LedgerVO.class));

        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<LedgerEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Ledger-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refLedgerData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<LedgerVO>> refLedgerData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                         String condition,
                                                         String searchObject,
                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<LedgerEntity> page = service.queryPage(param, false);
        IPage<LedgerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), LedgerVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }


}

==> ejc-law-impl-3.0.0-20230830.070935-46-sources.jar: com/ejianc/business/law/controller/LedgerController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.*;
import com.ejianc.business.law.service.*;
import com.ejianc.business.law.vo.*;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

/**
 * 案件台账
 *
 * @author generator
 */
@Controller
@RequestMapping("ledger")
public class LedgerController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ILedgerService service;

    @Autowired
    private ICaseRegisteService caseRegisteService;

    @Autowired
    private IProsecutionCaseRegisterService prosecutionCaseRegisterService;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<LedgerVO> saveOrUpdate(@RequestBody LedgerVO saveOrUpdateVO) {
        LedgerEntity entity = BeanMapper.map(saveOrUpdateVO, LedgerEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            } else {
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);
        LedgerVO vo = BeanMapper.map(entity, LedgerVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }


    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @Autowired
    private IInfoRegisterService infoRegisterService;
    @Autowired
    private IFrozenFundService frozenFundService;
    @Autowired
    private IThawFundService thawFundService;

    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<LedgerVO> queryDetail(Long id) {
//        LedgerEntity entity = service.selectById(id);
        CaseRegisteEntity caseRegisteEntity = caseRegisteService.selectById(id);

        LedgerVO vo = BeanMapper.map(caseRegisteEntity, LedgerVO.class);

        List<InfoRegisterEntity> infoRegisterEntity = infoRegisterService.list(Wrappers.<InfoRegisterEntity>lambdaQuery()
                .eq(InfoRegisterEntity::getCaseId, caseRegisteEntity.getId()));
        List<FrozenFundEntity> frozenFundEntity = frozenFundService.list(Wrappers.<FrozenFundEntity>lambdaQuery()
                .eq(FrozenFundEntity::getCaseId, caseRegisteEntity.getId()));
        List<ThawFundEntity> thawFundEntity = thawFundService.list(Wrappers.<ThawFundEntity>lambdaQuery()
                .eq(ThawFundEntity::getCaseId, caseRegisteEntity.getId()));
        //转换类型
        List<InfoRegisterVO> infoRegisterVOS = BeanMapper.mapList(infoRegisterEntity, InfoRegisterVO.class);
        List<FrozenFundVO> frozenFundVO = BeanMapper.mapList(frozenFundEntity, FrozenFundVO.class);
        List<ThawFundVO> thawFundVO = BeanMapper.mapList(thawFundEntity, ThawFundVO.class);
        //封装返回
        vo.setEndDate(caseRegisteEntity.getFirstEndDate());
        vo.setEndAmount(caseRegisteEntity.getFirstEndAmount());
        vo.setCaseResultId(caseRegisteEntity.getFirstResultId());
        vo.setCaseResultName(caseRegisteEntity.getFirstResultName());
        vo.setPlaintiffName(caseRegisteEntity.getPlaintiffMainName());


        vo.setInfoRegisterVOS(infoRegisterVOS);
        vo.setFrozenFundVOS(frozenFundVO);
        vo.setThawFundVOS(thawFundVO);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<LedgerVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (LedgerVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(LedgerVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<LedgerVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("caseCode");
        fuzzyFields.add("departmentName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("projectName");
        fuzzyFields.add("plaintiffName");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            //普通组织
            commonOrgIds.add(org.getId());

        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        if(param.getParams().get("caseType") != null){
            String caseType = param.getParams().get("caseType").getValue().toString();
            param.getParams().remove("caseType");
            if(caseType.equals("1")){
                IPage<CaseRegisteEntity> page = caseRegisteService.queryPage(param, false);
                IPage<LedgerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
                List<LedgerVO> ledgerVOS = new ArrayList<>();
                for (CaseRegisteEntity record : page.getRecords()) {
                    LedgerVO ledgerVO = BeanMapper.map(record, LedgerVO.class);
                    ledgerVO.setEndDate(record.getFirstEndDate());
                    ledgerVO.setEndAmount(record.getFirstEndAmount());
                    ledgerVO.setCaseResultId(record.getFirstResultId());
                    ledgerVO.setCaseResultName(record.getFirstResultName());
                    ledgerVO.setPlaintiffName(record.getPlaintiffMainName());
                    ledgerVOS.add(ledgerVO);
                }
                pageData.setRecords(ledgerVOS);

                return CommonResponse.success("查询列表数据成功！", pageData);
            } else {
                IPage<ProsecutionCaseRegisterEntity> page = prosecutionCaseRegisterService.queryPage(param, false);
                IPage<LedgerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());

                pageData.setRecords(BeanMapper.mapList(pageData.getRecords(),LedgerVO.class));

                return CommonResponse.success("查询列表数据成功！", pageData);
            }
        }
        return CommonResponse.error("请先选择案件类型！");

    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<LedgerEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("Ledger-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refLedgerData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<LedgerVO>> refLedgerData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                         String condition,
                                                         String searchObject,
                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<LedgerEntity> page = service.queryPage(param, false);
        IPage<LedgerVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), LedgerVO.class));

        return CommonResponse.success("查询参照数据成功！", pageData);
    }


}
